==> Cluckshrooms%281.21%29-1.1.2-sources.jar: fun/wich/client/CluckshroomEntityModel.java <==
package fun.wich.client;

import fun.wich.CluckshroomEntity;
import net.minecraft.class_558;
import net.minecraft.class_5603;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_630;
import net.minecraft.client.model.*;

public class CluckshroomEntityModel extends class_558<CluckshroomEntity> {
	protected final class_630 body;
	protected final class_630 body_mushroom;
	public CluckshroomEntityModel(class_630 modelPart) {
		super(modelPart);
		this.body = modelPart.method_32086("body");
		this.body_mushroom = this.body.method_32086("body_mushroom");
	}
	public static class_5607 method_31988() {
		class_5609 modelData = new class_5609();
		class_5610 modelPartData = modelData.method_32111();
		modelPartData.method_32117("head", class_5606.method_32108().method_32101(0, 0).method_32097(-2.0F, -6.0F, -2.0F, 4.0F, 6.0F, 3.0F), class_5603.method_32090(0.0F, 15.0F, -4.0F));
		modelPartData.method_32117("beak", class_5606.method_32108().method_32101(14, 0).method_32097(-2.0F, -4.0F, -4.0F, 4.0F, 2.0F, 2.0F), class_5603.method_32090(0.0F, 15.0F, -4.0F));
		modelPartData.method_32117("red_thing", class_5606.method_32108().method_32101(14, 4).method_32097(-1.0F, -2.0F, -3.0F, 2.0F, 2.0F, 2.0F), class_5603.method_32090(0.0F, 15.0F, -4.0F));
		modelPartData.method_32117("body", class_5606.method_32108().method_32101(0, 9).method_32097(-3.0F, -4.0F, -3.0F, 6.0F, 8.0F, 6.0F), class_5603.method_32091(0.0F, 16.0F, 0.0F, ((float)Math.PI / 2F), 0.0F, 0.0F));
		class_5606 modelPartBuilder = class_5606.method_32108().method_32101(26, 0).method_32097(-1.0F, 0.0F, -3.0F, 3.0F, 5.0F, 3.0F);
		modelPartData.method_32117("right_leg", modelPartBuilder, class_5603.method_32090(-2.0F, 19.0F, 1.0F));
		modelPartData.method_32117("left_leg", modelPartBuilder, class_5603.method_32090(1.0F, 19.0F, 1.0F));
		modelPartData.method_32117("right_wing", class_5606.method_32108().method_32101(24, 13).method_32097(0.0F, 0.0F, -3.0F, 1.0F, 4.0F, 6.0F), class_5603.method_32090(-4.0F, 13.0F, 0.0F));
		modelPartData.method_32117("left_wing", class_5606.method_32108().method_32101(24, 13).method_32097(-1.0F, 0.0F, -3.0F, 1.0F, 4.0F, 6.0F), class_5603.method_32090(4.0F, 13.0F, 0.0F));
		//Head Mushroom
		class_5610 head = modelPartData.method_32116("head");
		head.method_32117("head_mushroom_2", class_5606.method_32108().method_32101(38, 14).method_32097(0, -4, -2.5F, 0, 4, 5), class_5603.method_32091(0, -6, -0.5F, 0, 0.7854F, 0));
		head.method_32117("head_mushroom_1", class_5606.method_32108().method_32101(38, 14).method_32097(0, -4, -2.5F, 0, 4, 5), class_5603.method_32091(0, -6, -0.5F, 0, -0.7854F, 0));
		//Body Mushroom
		class_5610 body = modelPartData.method_32116("body");
		class_5610 body_mushroom = body.method_32117("body_mushroom", class_5606.method_32108(), class_5603.method_32090(0, 8, 0));
		body_mushroom.method_32117("head_mushroom_2", class_5606.method_32108().method_32101(38, 9).method_32097(0, -2.5F, 0, 0, 5, 5), class_5603.method_32091(0, -7.5F, 3, 0, 0, -0.7854F));
		body_mushroom.method_32117("head_mushroom_1", class_5606.method_32108().method_32101(38, 9).method_32097(0, -2.5F, 0, 0, 5, 5), class_5603.method_32091(0, -7.5F, 3, 0, 0, 0.7854F));
		return class_5607.method_32110(modelData, 64, 32);
	}
	@Override
	public void animateModel(CluckshroomEntity state, float f, float g, float h) {
		super.method_2816(state, f, g, h);
		this.body_mushroom.field_3665 = !state.method_6109();
	}
}

==> Cluckshrooms%281.21.2%29-1.1.1-sources.jar: fun/wich/client/CluckshroomEntityModel.java <==
package fun.wich.client;

import net.minecraft.class_10009;
import net.minecraft.class_558;
import net.minecraft.class_5603;
import net.minecraft.class_5606;
import net.minecraft.class_5607;
import net.minecraft.class_5609;
import net.minecraft.class_5610;
import net.minecraft.class_630;
import net.minecraft.class_9941;
import net.minecraft.class_9953;
import net.minecraft.client.model.*;
import java.util.Set;

public class CluckshroomEntityModel extends class_558 {
	protected final class_630 body;
	protected final class_630 body_mushroom;
	public static final class_9953 BABY_CLUCKSHROOM_TRANSFORMER = new class_9941(false, 5.0F, 2.0F, 2.0F, 1.99F, 24.0F, Set.of("head", "beak", "red_thing", "head_mushroom_1", "head_mushroom_2"));
	public CluckshroomEntityModel(class_630 modelPart) {
		super(modelPart);
		this.body = field_54014.method_32086("body");
		this.body_mushroom = this.body.method_32086("body_mushroom");
	}
	public static class_5607 method_31988() {
		class_5609 modelData = new class_5609();
		class_5610 modelPartData = modelData.method_32111();
		modelPartData.method_32117("head", class_5606.method_32108().method_32101(0, 0).method_32097(-2.0F, -6.0F, -2.0F, 4.0F, 6.0F, 3.0F), class_5603.method_32090(0.0F, 15.0F, -4.0F));
		modelPartData.method_32117("beak", class_5606.method_32108().method_32101(14, 0).method_32097(-2.0F, -4.0F, -4.0F, 4.0F, 2.0F, 2.0F), class_5603.method_32090(0.0F, 15.0F, -4.0F));
		modelPartData.method_32117("red_thing", class_5606.method_32108().method_32101(14, 4).method_32097(-1.0F, -2.0F, -3.0F, 2.0F, 2.0F, 2.0F), class_5603.method_32090(0.0F, 15.0F, -4.0F));
		modelPartData.method_32117("body", class_5606.method_32108().method_32101(0, 9).method_32097(-3.0F, -4.0F, -3.0F, 6.0F, 8.0F, 6.0F), class_5603.method_32091(0.0F, 16.0F, 0.0F, ((float)Math.PI / 2F), 0.0F, 0.0F));
		class_5606 modelPartBuilder = class_5606.method_32108().method_32101(26, 0).method_32097(-1.0F, 0.0F, -3.0F, 3.0F, 5.0F, 3.0F);
		modelPartData.method_32117("right_leg", modelPartBuilder, class_5603.method_32090(-2.0F, 19.0F, 1.0F));
		modelPartData.method_32117("left_leg", modelPartBuilder, class_5603.method_32090(1.0F, 19.0F, 1.0F));
		modelPartData.method_32117("right_wing", class_5606.method_32108().method_32101(24, 13).method_32097(0.0F, 0.0F, -3.0F, 1.0F, 4.0F, 6.0F), class_5603.method_32090(-4.0F, 13.0F, 0.0F));
		modelPartData.method_32117("left_wing", class_5606.method_32108().method_32101(24, 13).method_32097(-1.0F, 0.0F, -3.0F, 1.0F, 4.0F, 6.0F), class_5603.method_32090(4.0F, 13.0F, 0.0F));
		//Head Mushroom
		class_5610 head = modelPartData.method_32116("head");
		head.method_32117("head_mushroom_2", class_5606.method_32108().method_32101(38, 14).method_32097(0, -4, -2.5F, 0, 4, 5), class_5603.method_32091(0, -6, -0.5F, 0, 0.7854F, 0));
		head.method_32117("head_mushroom_1", class_5606.method_32108().method_32101(38, 14).method_32097(0, -4, -2.5F, 0, 4, 5), class_5603.method_32091(0, -6, -0.5F, 0, -0.7854F, 0));
		//Body Mushroom
		class_5610 body = modelPartData.method_32116("body");
		class_5610 body_mushroom = body.method_32117("body_mushroom", class_5606.method_32108(), class_5603.method_32090(0, 8, 0));
		body_mushroom.method_32117("head_mushroom_2", class_5606.method_32108().method_32101(38, 9).method_32097(0, -2.5F, 0, 0, 5, 5), class_5603.method_32091(0, -7.5F, 3, 0, 0, -0.7854F));
		body_mushroom.method_32117("head_mushroom_1", class_5606.method_32108().method_32101(38, 9).method_32097(0, -2.5F, 0, 0, 5, 5), class_5603.method_32091(0, -7.5F, 3, 0, 0, 0.7854F));
		return class_5607.method_32110(modelData, 64, 32);
	}
	@Override
	public void method_62073(class_10009 state) {
		super.method_62073(state);
		this.body_mushroom.field_3665 = !state.field_53457;
	}
}
